@@ -1,4 +1,4 @@
-/* 
+/*
    test durability
 */
 
@@ -9,7 +9,9 @@ var conn = null;
 
 function checkNoJournalFiles(path, pass) {
     var files = listFiles(path);
-    if (files.some(function (f) { return f.name.indexOf("prealloc") < 0; })) {
+    if (files.some(function(f) {
+            return f.name.indexOf("prealloc") < 0;
+        })) {
         if (pass == null) {
             // wait a bit longer for mongod to potentially finish if it is still running.
             sleep(10000);
@@ -44,31 +46,26 @@ function runDiff(a, b) {
 
 function log(str) {
     print();
-    if(str)
-        print(testname+" step " + step++ + " " + str);
+    if (str)
+        print(testname + " step " + step++ + " " + str);
     else
-        print(testname+" step " + step++);
+        print(testname + " step " + step++);
 }
 
-// if you do inserts here, you will want to set _id.  otherwise they won't match on different 
+// if you do inserts here, you will want to set _id.  otherwise they won't match on different
 // runs so we can't do a binary diff of the resulting files to check they are consistent.
 function work() {
     log("work");
     var d = conn.getDB("test");
-    d.foo.insert({ _id: 3, x: 22 });
-    d.foo.insert({ _id: 4, x: 22 });
-    d.a.insert({ _id: 3, x: 22, y: [1, 2, 3] });
-    d.a.insert({ _id: 4, x: 22, y: [1, 2, 3] });
-    d.a.update({ _id: 4 }, { $inc: { x: 1} });
+    d.foo.insert({_id: 3, x: 22});
+    d.foo.insert({_id: 4, x: 22});
+    d.a.insert({_id: 3, x: 22, y: [1, 2, 3]});
+    d.a.insert({_id: 4, x: 22, y: [1, 2, 3]});
+    d.a.update({_id: 4}, {$inc: {x: 1}});
 
-    // try building an index.  however, be careful as object id's in system.indexes would vary, so we do it manually:
-    d.system.indexes.insert({ _id: 99, ns: "test.a", key: { x: 1 }, name: "x_1", v: 0 });
-
-//    d.a.update({ _id: 4 }, { $inc: { x: 1} });
-//    d.a.reIndex();
-
-    // assure writes applied in case we kill -9 on return from this function
-    d.getLastError();
+    // try building an index.  however, be careful as object id's in system.indexes would vary, so
+    // we do it manually:
+    d.system.indexes.insert({_id: 99, ns: "test.a", key: {x: 1}, name: "x_1"});
     log("endwork");
     return d;
 }
@@ -78,12 +75,12 @@ function addRows() {
     log("add rows " + rand);
     var d = conn.getDB("test");
     for (var j = 0; j < rand; ++j) {
-        d.rows.insert({a:1, b: "blah"});
+        d.rows.insert({a: 1, b: "blah"});
     }
     return rand;
 }
 
-function verify() { 
+function verify() {
     log("verify");
     var d = conn.getDB("test");
     assert.eq(d.foo.count(), 2, "collection count is wrong");
@@ -96,7 +93,7 @@ function verifyRows(nrows) {
     assert.eq(d.rows.count(), nrows, "collection count is wrong");
 }
 
-if( debugging ) { 
+if (debugging) {
     // mongod already running in debugger
     conn = db.getMongo();
     work();
@@ -107,43 +104,50 @@ if( debugging ) {
 log();
 
 // directories
-var path1 = "/data/db/" + testname+"nodur";
-var path2 = "/data/db/" + testname+"dur";
+var path1 = MongoRunner.dataPath + testname + "nodur";
+var path2 = MongoRunner.dataPath + testname + "dur";
 
 // non-durable version
-log("starting 30000");
-conn = startMongodEmpty("--port", 30000, "--dbpath", path1, "--nodur", "--smallfiles");
+log("starting first mongod");
+conn = MongoRunner.runMongod({dbpath: path1, nojournal: "", smallfiles: ""});
 work();
-stopMongod(30000);
+MongoRunner.stopMongod(conn);
 
 // hail mary for windows
-// Sat Jun 11 14:07:57 Error: boost::filesystem::create_directory: Access is denied: "\data\db\manyRestartsdur" (anon):1
+// Sat Jun 11 14:07:57 Error: boost::filesystem::create_directory: Access is denied:
+// "\data\db\manyRestartsdur" (anon):1
 sleep(1000);
 
-log("starting 30001");
-conn = startMongodEmpty("--port", 30001, "--dbpath", path2, "--dur", "--smallfiles", "--durOptions", 8);
+log("starting second mongod");
+conn = MongoRunner.runMongod({dbpath: path2, journal: "", smallfiles: "", journalOptions: 8});
 work();
 // wait for group commit.
-printjson(conn.getDB('admin').runCommand({getlasterror:1, fsync:1}));
+printjson(conn.getDB('admin').runCommand({getlasterror: 1, fsync: 1}));
 
-stopMongod(30001);
+MongoRunner.stopMongod(conn);
 sleep(5000);
 
 for (var i = 0; i < 3; ++i) {
-
     // durable version
-    log("restarting 30001");
-    conn = startMongodNoReset("--port", 30001, "--dbpath", path2, "--dur", "--smallfiles", "--durOptions", 8);
+    log("restarting second mongod");
+    conn = MongoRunner.runMongod({
+        restart: true,
+        cleanData: false,
+        dbpath: path2,
+        journal: "",
+        smallfiles: "",
+        journalOptions: 8
+    });
 
     // wait for group commit.
-    printjson(conn.getDB('admin').runCommand({getlasterror:1, fsync:1}));
-    
+    printjson(conn.getDB('admin').runCommand({getlasterror: 1, fsync: 1}));
+
     verify();
-    
+
     // kill the process hard
     log("hard kill");
-    stopMongod(30001, /*signal*/9);
-    
+    MongoRunner.stopMongod(conn, /*signal*/ 9);
+
     sleep(5000);
 }
 
@@ -151,11 +155,18 @@ for (var i = 0; i < 3; ++i) {
 
 // restart and recover
 log("restart");
-conn = startMongodNoReset("--port", 30002, "--dbpath", path2, "--dur", "--smallfiles", "--durOptions", 8);
+conn = MongoRunner.runMongod({
+    restart: true,
+    cleanData: false,
+    dbpath: path2,
+    journal: "",
+    smallfiles: "",
+    journalOptions: 8
+});
 log("verify");
 verify();
 log("stop");
-stopMongod(30002);
+MongoRunner.stopMongod(conn);
 sleep(5000);
 
 // at this point, after clean shutdown, there should be no journal files
@@ -174,22 +185,27 @@ log("check data matches done");
 
 var nrows = 0;
 for (var i = 0; i < 5; ++i) {
-
     // durable version
-    log("restarting 30001");
-    conn = startMongodNoReset("--port", 30001, "--dbpath", path2, "--dur", "--smallfiles", "--durOptions", 8);
+    log("restarting second mongod");
+    conn = MongoRunner.runMongod({
+        restart: true,
+        cleanData: false,
+        dbpath: path2,
+        journal: "",
+        smallfiles: "",
+        journalOptions: 8
+    });
     nrows += addRows();
     // wait for group commit.
-    printjson(conn.getDB('admin').runCommand({getlasterror:1, fsync:1}));
-    
+    printjson(conn.getDB('admin').runCommand({getlasterror: 1, fsync: 1}));
+
     verifyRows(nrows);
-    
+
     // kill the process hard
     log("hard kill");
-    stopMongod(30001, /*signal*/9);
-    
+    MongoRunner.stopMongod(conn, /*signal*/ 9);
+
     sleep(5000);
 }
 
 print(testname + " SUCCESS");
-
