@@ -18,7 +18,6 @@
 // }
 //
 function DataGenerator() {
-
     var hexChars = "0123456789abcdefABCDEF";
     var regexOptions = "igm";
     var stringChars = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
@@ -26,52 +25,54 @@ function DataGenerator() {
 
     // Generator functions
     // BSON Type: -1
-    function GenMinKey (seed) {
-        return MinKey()
+    function GenMinKey(seed) {
+        return MinKey();
     }
     // BSON Type: 0 (EOO)
     // No Shell Equivalent
     // BSON Type: 1
-    function GenNumberDouble (seed) {
+    function GenNumberDouble(seed) {
         var seed = seed || 0;
-        return Number(seed)
+        return Number(seed);
     }
     // BSON Type: 2
-    function GenString (seed) {
+    function GenString(seed) {
         var seed = seed || 0;
         var text = "";
 
-        for (var i=0; i < (seed % 1000) + 1; i++) {
+        for (var i = 0; i < (seed % 1000) + 1; i++) {
             text += stringChars.charAt((seed + (i % 10)) % stringChars.length);
         }
 
         return text;
     }
     // Javascript Dates get stored as strings
-    function GenDate (seed) {
+    function GenDate(seed) {
         // The "Date" constructor without "new" ignores its arguments anyway, so don't bother
         // using the seed.
         return Date();
     }
     // BSON Type: 3
-    function GenObject (seed) {
+    function GenObject(seed) {
         var seed = seed || 0;
 
-        return { "object" : true };
+        return {
+            "object": true
+        };
     }
     // BSON Type: 4
-    function GenArray (seed) {
+    function GenArray(seed) {
         var seed = seed || 0;
 
-        return [ "array", true ];
+        return ["array", true];
     }
     // BSON Type: 5
-    function GenBinData (seed) {
+    function GenBinData(seed) {
         var seed = seed || 0;
 
         var text = "";
 
-        for (var i=0; i < (seed % 1000) + 1; i++) {
+        for (var i = 0; i < (seed % 1000) + 1; i++) {
             text += base64Chars.charAt((seed + (i % 10)) % base64Chars.length);
         }
 
@@ -82,29 +83,29 @@ function DataGenerator() {
         return BinData(seed % 6, text);
     }
     // BSON Type: 6
-    function GenUndefined (seed) {
+    function GenUndefined(seed) {
         return undefined;
     }
     // BSON Type: 7
-    function GenObjectId (seed) {
+    function GenObjectId(seed) {
         var seed = seed || 0;
         var hexString = "";
 
-        for (var i=0; i < 24; i++) {
+        for (var i = 0; i < 24; i++) {
             hexString += hexChars.charAt((seed + (i % 10)) % hexChars.length);
         }
 
         return ObjectId(hexString);
     }
     // BSON Type: 8
-    function GenBool (seed) {
+    function GenBool(seed) {
         var seed = seed || 0;
 
         return (seed % 2) === 0;
     }
     // BSON Type: 9
     // Our ISODate constructor equals the Date BSON type
-    function GenISODate (seed) {
+    function GenISODate(seed) {
         var seed = seed || 0;
 
         var year = (seed % (2037 - 1970)) + 1970;
@@ -116,7 +117,6 @@ function DataGenerator() {
         var millis = seed % 1000;
 
         function pad(number, length) {
-
             var str = '' + number;
 
             while (str.length < length) {
@@ -126,32 +126,32 @@ function DataGenerator() {
             return str;
         }
 
-        return ISODate(pad(year, 4) + "-" + pad(month, 2) + "-" + pad(day, 2) + "T" +
-                       pad(hour, 2) + ":" + pad(minute, 2) + ":" + pad(second, 2) + "." + pad(millis, 3));
+        return ISODate(pad(year, 4) + "-" + pad(month, 2) + "-" + pad(day, 2) + "T" + pad(hour, 2) +
+                       ":" + pad(minute, 2) + ":" + pad(second, 2) + "." + pad(millis, 3));
     }
     // BSON Type: 10
-    function GenNull (seed) {
+    function GenNull(seed) {
         return null;
     }
     // BSON Type: 11
-    function GenRegExp (seed) {
+    function GenRegExp(seed) {
         var seed = seed || 0;
         var options = "";
 
-        for (var i=0; i < (seed % 3) + 1; i++) {
+        for (var i = 0; i < (seed % 3) + 1; i++) {
             options += regexOptions.charAt((seed + (i % 10)) % regexOptions.length);
         }
 
         return RegExp(GenString(seed), options);
     }
-    function GenRegExpLiteral (seed) {
+    function GenRegExpLiteral(seed) {
         // We can't pass variables to a regex literal, so we can't programmatically generate the
         // data.  Instead we rely on the "RegExp" constructor.
         return /regexliteral/;
     }
     // BSON Type: 12
     // The DBPointer type in the shell equals the DBRef BSON type
-    function GenDBPointer (seed) {
+    function GenDBPointer(seed) {
         var seed = seed || 0;
 
         return DBPointer(GenString(seed), GenObjectId(seed));
@@ -163,13 +163,13 @@ function DataGenerator() {
     // BSON Type: 15 (CodeWScope)
     // No Shell Equivalent
     // BSON Type: 16
-    function GenNumberInt (seed) {
+    function GenNumberInt(seed) {
         var seed = seed || 0;
 
         return NumberInt(seed);
     }
     // BSON Type: 17
-    function GenTimestamp (seed) {
+    function GenTimestamp(seed) {
         var seed = seed || 0;
 
         // Make sure our timestamp is not zero, because that doesn't round trip from 2.4 to latest.
@@ -181,17 +181,17 @@ function DataGenerator() {
         return Timestamp(seed, (seed * 100000) / 99999);
     }
     // BSON Type: 18
-    function GenNumberLong (seed) {
+    function GenNumberLong(seed) {
         var seed = seed || 0;
 
-        return NumberLong(seed)
+        return NumberLong(seed);
     }
     // BSON Type: 127
-    function GenMaxKey (seed) {
-        return MaxKey()
+    function GenMaxKey(seed) {
+        return MaxKey();
     }
     // The DBRef type is not a BSON type but is treated specially in the shell:
-    function GenDBRef (seed) {
+    function GenDBRef(seed) {
         var seed = seed || 0;
 
         return DBRef(GenString(seed), GenObjectId(seed));
@@ -199,34 +199,34 @@ function DataGenerator() {
 
     function GenFlatObjectAllTypes(seed) {
         return {
-            "MinKey" : GenMinKey(seed),
-            "NumberDouble" : GenNumberDouble(seed),
-            "String" : GenString(seed),
+            "MinKey": GenMinKey(seed),
+            "NumberDouble": GenNumberDouble(seed),
+            "String": GenString(seed),
             // Javascript Dates get stored as strings
-            "Date" : GenDate(seed),
+            "Date": GenDate(seed),
             // BSON Type: 3
-            "Object" : GenObject(seed),
+            "Object": GenObject(seed),
             // BSON Type: 4
-            "Array" : GenArray(seed),
+            "Array": GenArray(seed),
             // BSON Type: 5
-            "BinData" : GenBinData(seed),
+            "BinData": GenBinData(seed),
             // BSON Type: 6
-            "Undefined" : undefined,
+            "Undefined": undefined,
             // BSON Type: 7
-            "jstOID" : GenObjectId(seed),
+            "jstOID": GenObjectId(seed),
             // BSON Type: 8
-            "Bool" : GenBool(seed),
+            "Bool": GenBool(seed),
             // BSON Type: 9
             // Our ISODate constructor equals the Date BSON type
-            "ISODate" : GenISODate(seed),
+            "ISODate": GenISODate(seed),
             // BSON Type: 10
-            "jstNULL" : GenNull(seed),
+            "jstNULL": GenNull(seed),
             // BSON Type: 11
-            "RegExp" : GenRegExp(seed),
-            "RegExpLiteral" : GenRegExpLiteral(seed),
+            "RegExp": GenRegExp(seed),
+            "RegExpLiteral": GenRegExpLiteral(seed),
             // BSON Type: 12
             // The DBPointer type in the shell equals the DBRef BSON type
-            "DBPointer" : GenDBPointer(seed),
+            "DBPointer": GenDBPointer(seed),
             // BSON Type: 13 (Code)
             // No Shell Equivalent
             // BSON Type: 14 (Symbol)
@@ -234,54 +234,54 @@ function DataGenerator() {
             // BSON Type: 15 (CodeWScope)
             // No Shell Equivalent
             // BSON Type: 16
-            "NumberInt" : GenNumberInt(seed),
+            "NumberInt": GenNumberInt(seed),
             // BSON Type: 17
-            "Timestamp" : GenTimestamp(seed),
+            "Timestamp": GenTimestamp(seed),
             // BSON Type: 18
-            "NumberLong" : GenNumberLong(seed),
+            "NumberLong": GenNumberLong(seed),
             // BSON Type: 127
-            "MaxKey" : GenMaxKey(seed),
+            "MaxKey": GenMaxKey(seed),
             // The DBRef type is not a BSON type but is treated specially in the shell:
-            "DBRef" : GenDBRef(seed),
-        }
+            "DBRef": GenDBRef(seed),
+        };
     }
 
     function GenFlatObjectAllTypesHardCoded() {
         return {
             // BSON Type: -1
-            "MinKey" : MinKey(),
+            "MinKey": MinKey(),
             // BSON Type: 0 (EOO)
             // No Shell Equivalent
             // BSON Type: 1
-            "NumberDouble" : Number(4.0),
+            "NumberDouble": Number(4.0),
             // BSON Type: 2
-            "String" : "string",
+            "String": "string",
             // Javascript Dates get stored as strings
-            "Date" : Date("2013-12-11T19:38:24.055Z"),
-            "Date2" : GenDate(10000),
+            "Date": Date("2013-12-11T19:38:24.055Z"),
+            "Date2": GenDate(10000),
             // BSON Type: 3
-            "Object" : { "object" : true },
+            "Object": {"object": true},
             // BSON Type: 4
-            "Array" : [ "array", true ],
+            "Array": ["array", true],
             // BSON Type: 5
-            "BinData" : BinData(0, "aaaa"),
+            "BinData": BinData(0, "aaaa"),
             // BSON Type: 6
-            "Undefined" : undefined,
+            "Undefined": undefined,
             // BSON Type: 7
-            "jstOID" : ObjectId("aaaaaaaaaaaaaaaaaaaaaaaa"),
+            "jstOID": ObjectId("aaaaaaaaaaaaaaaaaaaaaaaa"),
             // BSON Type: 8
-            "Bool" : true,
+            "Bool": true,
             // BSON Type: 9
             // Our ISODate constructor equals the Date BSON type
-            "ISODate" : ISODate("2013-12-11T19:38:24.055Z"),
+            "ISODate": ISODate("2013-12-11T19:38:24.055Z"),
             // BSON Type: 10
-            "jstNULL" : null,
+            "jstNULL": null,
             // BSON Type: 11
-            "RegEx" : RegExp("a"),
-            "RegEx" : /a/,
+            "RegExp": RegExp("a"),
+            "RegExpLiteral": /a/,
             // BSON Type: 12
             // The DBPointer type in the shell equals the DBRef BSON type
-            "DBPointer" : DBPointer("foo", ObjectId("bbbbbbbbbbbbbbbbbbbbbbbb")),
+            "DBPointer": DBPointer("foo", ObjectId("bbbbbbbbbbbbbbbbbbbbbbbb")),
             // BSON Type: 13 (Code)
             // No Shell Equivalent
             // BSON Type: 14 (Symbol)
@@ -289,16 +289,16 @@ function DataGenerator() {
             // BSON Type: 15 (CodeWScope)
             // No Shell Equivalent
             // BSON Type: 16
-            "NumberInt" : NumberInt(5),
+            "NumberInt": NumberInt(5),
             // BSON Type: 17
-            "Timestamp" : Timestamp(1,2),
+            "Timestamp": Timestamp(1, 2),
             // BSON Type: 18
-            "NumberLong" : NumberLong(6),
+            "NumberLong": NumberLong(6),
             // BSON Type: 127
-            "MaxKey" : MaxKey(),
+            "MaxKey": MaxKey(),
             // The DBRef type is not a BSON type but is treated specially in the shell:
-            "DBRef" : DBRef("bar", 2)
-        }
+            "DBRef": DBRef("bar", 2)
+        };
     }
 
     // Data we are using as a source for our testing
@@ -312,21 +312,21 @@ function DataGenerator() {
         GenFlatObjectAllTypes(23),
         GenFlatObjectAllTypes(111),
         GenFlatObjectAllTypes(11111111),
-    ]
+    ];
 
     // Cursor interface
     var i = 0;
     return {
-        "hasNext" : function () {
+        "hasNext": function() {
             return i < testData.length;
         },
-        "next" : function () {
+        "next": function() {
             if (i >= testData.length) {
                 return undefined;
             }
             return testData[i++];
         }
-    }
+    };
 }
 
 //
@@ -356,14 +356,15 @@ function DataGenerator() {
 // }
 //
 function IndexDataGenerator(options) {
-
     // getNextUniqueKey()
     //
     // This function returns a new key each time it is called and is guaranteed to not return
     // duplicates.
     //
-    // The sequence of values returned is a-z then A-Z.  When "Z" is reached, a new character is added
-    // and the first one wraps around, resulting in "aa".  The process is repeated, so we get a sequence
+    // The sequence of values returned is a-z then A-Z.  When "Z" is reached, a new character is
+    // added
+    // and the first one wraps around, resulting in "aa".  The process is repeated, so we get a
+    // sequence
     // like this:
     //
     // "a"
@@ -378,9 +379,8 @@ function IndexDataGenerator(options) {
     // ...
     var currentKey = "";
     function getNextUniqueKey() {
-
         function setCharAt(str, index, chr) {
-            if (index > str.length-1) {
+            if (index > str.length - 1) {
                 return str;
             }
             return str.substr(0, index) + chr + str.substr(index + 1);
@@ -401,14 +401,14 @@ function IndexDataGenerator(options) {
             // Find the character (index into keyChars) that we currently have at this position, set
             // this position to the next character in the keyChars sequence
             keyCharsIndex = keyChars.search(currentKey[currentKeyIndex]);
-            currentKey = setCharAt(currentKey, currentKeyIndex,
-                                   keyChars[(keyCharsIndex + 1) % keyChars.length]);
+            currentKey = setCharAt(
+                currentKey, currentKeyIndex, keyChars[(keyCharsIndex + 1) % keyChars.length]);
             currentKeyIndex = currentKeyIndex + 1;
 
             // Loop again if we advanced the character past the end of keyChars and wrapped around,
             // so that we can advance the next character over too.  For example, this is the case
             // where "ab" follows "Za".
-        } while (keyCharsIndex + 1 >= keyChars.length)
+        } while (keyCharsIndex + 1 >= keyChars.length);
 
         return currentKey;
     }
@@ -486,11 +486,10 @@ function IndexDataGenerator(options) {
             }
             if (propertyType == 1) {
                 attributes["sparse"] = true;
-            }
-            else {
+            } else {
                 // TODO:  We have to test this as a separate stage because we want to round trip
                 // multiple documents
-                //attributes["unique"] = true;
+                // attributes["unique"] = true;
             }
         }
         return attributes;
@@ -512,9 +511,12 @@ function IndexDataGenerator(options) {
             }
             if (propertyType == 2) {
                 attributes["max"] = ((seed + i) * 10000) % 100 + 10;
+            } else {
             }
-            else {
-            }
+        }
+        // The region specified in a 2d index must be positive
+        if (attributes["min"] >= attributes["max"]) {
+            attributes["max"] = attributes["min"] + attributes["max"];
         }
         return attributes;
     }
@@ -532,7 +534,7 @@ function IndexDataGenerator(options) {
         // When using a text index, the following additional index properties are required when
         // downgrading from 2.6:
         // { "textIndexVersion" : 1 }
-        attributes["textIndexVersion"] = 1
+        attributes["textIndexVersion"] = 1;
         return attributes;
     }
 
@@ -541,60 +543,60 @@ function IndexDataGenerator(options) {
         // When using a 2dsphere index, the following additional index properties are required when
         // downgrading from 2.6:
         // { "2dsphereIndexVersion" : 1 }
-        attributes["2dsphereIndexVersion"] = 1
+        attributes["2dsphereIndexVersion"] = 1;
         return attributes;
     }
 
     testIndexes = [
         // Single Field Indexes
-        { "spec" : GenSingleFieldIndex(1), "options" : GenIndexOptions(0) },
-        { "spec" : GenSingleFieldIndex(0), "options" : GenIndexOptions(1) },
+        {"spec": GenSingleFieldIndex(1), "options": GenIndexOptions(0)},
+        {"spec": GenSingleFieldIndex(0), "options": GenIndexOptions(1)},
 
         // Compound Indexes
-        { "spec" : GenCompoundIndex(0), "options" : GenIndexOptions(2) },
-        { "spec" : GenCompoundIndex(1), "options" : GenIndexOptions(3) },
-        { "spec" : GenCompoundIndex(2), "options" : GenIndexOptions(4) },
-        { "spec" : GenCompoundIndex(3), "options" : GenIndexOptions(5) },
-        { "spec" : GenCompoundIndex(4), "options" : GenIndexOptions(6) },
-        { "spec" : GenCompoundIndex(5), "options" : GenIndexOptions(7) },
-        { "spec" : GenCompoundIndex(6), "options" : GenIndexOptions(8) },
+        {"spec": GenCompoundIndex(0), "options": GenIndexOptions(2)},
+        {"spec": GenCompoundIndex(1), "options": GenIndexOptions(3)},
+        {"spec": GenCompoundIndex(2), "options": GenIndexOptions(4)},
+        {"spec": GenCompoundIndex(3), "options": GenIndexOptions(5)},
+        {"spec": GenCompoundIndex(4), "options": GenIndexOptions(6)},
+        {"spec": GenCompoundIndex(5), "options": GenIndexOptions(7)},
+        {"spec": GenCompoundIndex(6), "options": GenIndexOptions(8)},
 
         // Multikey Indexes
         // (Same index spec as single field)
 
         // Nested Indexes
-        { "spec" : GenNestedIndex(0), "options" : GenIndexOptions(9) },
-        { "spec" : GenNestedIndex(1), "options" : GenIndexOptions(10) },
-        { "spec" : GenNestedIndex(2), "options" : GenIndexOptions(11) },
+        {"spec": GenNestedIndex(0), "options": GenIndexOptions(9)},
+        {"spec": GenNestedIndex(1), "options": GenIndexOptions(10)},
+        {"spec": GenNestedIndex(2), "options": GenIndexOptions(11)},
 
         // Geospatial Indexes
         //   2dsphere
-        { "spec" : Gen2dsphereIndex(7), "options" : Gen2dSphereIndexOptions(12) },
+        {"spec": Gen2dsphereIndex(7), "options": Gen2dSphereIndexOptions(12)},
         //   2d
-        { "spec" : Gen2dIndex(8), "options" : Gen2dIndexOptions(13) },
+        {"spec": Gen2dIndex(8), "options": Gen2dIndexOptions(13)},
         //   Haystack
-        { "spec" : GenHaystackIndex(9), "options" : GenHaystackIndexOptions(13) },
+        {"spec": GenHaystackIndex(9), "options": GenHaystackIndexOptions(13)},
 
         // Text Indexes
-        { "spec" : GenTextIndex(10), "options" : GenTextIndexOptions(14) },
+        {"spec": GenTextIndex(10), "options": GenTextIndexOptions(14)},
 
         // Hashed Index
-        { "spec" : GenHashedIndex(10), "options" : GenIndexOptions(14) },
-    ]
+        {"spec": GenHashedIndex(10), "options": GenIndexOptions(14)},
+    ];
 
     // Cursor interface
     var i = 0;
     return {
-        "hasNext" : function () {
+        "hasNext": function() {
             return i < testIndexes.length;
         },
-        "next" : function () {
+        "next": function() {
             if (i >= testIndexes.length) {
                 return undefined;
             }
             return testIndexes[i++];
         }
-    }
+    };
 }
 
 //
@@ -616,7 +618,6 @@ function IndexDataGenerator(options) {
 // var metadata = generator.get();
 //
 function CollectionMetadataGenerator(options) {
-
     var capped = true;
     var options = options || {};
 
@@ -624,35 +625,37 @@ function CollectionMetadataGenerator(options) {
         if (options.hasOwnProperty(option)) {
             if (option === 'capped') {
                 if (typeof(options['capped']) !== 'boolean') {
-                    throw "\"capped\" options must be boolean in CollectionMetadataGenerator";
+                    throw Error(
+                        "\"capped\" options must be boolean in CollectionMetadataGenerator");
                 }
                 capped = options['capped'];
-            }
-            else {
-                throw "Unsupported key in options passed to CollectionMetadataGenerator: " + option;
+            } else {
+                throw Error("Unsupported key in options passed to CollectionMetadataGenerator: " +
+                            option);
             }
         }
     }
 
     // Collection metadata we are using as a source for testing
-    //db.createCollection(name, {capped: <Boolean>, autoIndexId: <Boolean>, size: <number>, max <number>} )
+    // db.createCollection(name, {capped: <Boolean>, autoIndexId: <Boolean>, size: <number>, max
+    // <number>} )
     var cappedCollectionMetadata = {
-        "capped" : true,
-        "size" : 100000,
-        "max" : 2000,
-        "usePowerOf2Sizes" : true,
+        "capped": true,
+        "size": 100000,
+        "max": 2000,
+        "usePowerOf2Sizes": true,
         //"autoIndexId" : false // XXX: this doesn't exist in 2.4
-    }
+    };
     // We need to explicitly enable usePowerOf2Sizes, since it's the default in 2.6 but not in 2.4
     var normalCollectionMetadata = {
-        "usePowerOf2Sizes" : true
+        "usePowerOf2Sizes": true
     };
 
     return {
-        "get" : function () {
+        "get": function() {
             return capped ? cappedCollectionMetadata : normalCollectionMetadata;
         }
-    }
+    };
 }
 
 //
@@ -660,8 +663,8 @@ function CollectionMetadataGenerator(options) {
 //
 function CollectionDataGenerator(options) {
     return {
-        "data" : new DataGenerator(),
-        "indexes" : new IndexDataGenerator(),
-        "collectionMetadata" : new CollectionMetadataGenerator(options)
-    }
+        "data": new DataGenerator(),
+        "indexes": new IndexDataGenerator(),
+        "collectionMetadata": new CollectionMetadataGenerator(options)
+    };
 }
