@@ -8,12 +8,10 @@
 // the only node is running at a profiling level of 2.
 var collectionName = 'jstests_replsetadd_profile';
 
-var replTest = new ReplSetTest({name: 'ReplSetAddProfileTestSet',
-                                nodes: [{profile: 2}],
-                                host: "localhost"});
+var replTest = new ReplSetTest({name: 'ReplSetAddProfileTestSet', nodes: [{profile: 2}]});
 replTest.startSet();
 replTest.initiate();
-var master = replTest.getMaster();
+var master = replTest.getPrimary();
 var masterCollection = master.getDB('test').getCollection(collectionName);
 masterCollection.save({a: 1});
 
@@ -21,12 +19,14 @@ masterCollection.save({a: 1});
 var newNode = replTest.add();
 replTest.reInitiate();
 
+replTest.waitForState(replTest.nodes[1], ReplSetTest.State.SECONDARY, 60 * 1000);
 // Allow documents to propagate to new replica set member.
 replTest.awaitReplication();
 
 var newNodeCollection = newNode.getDB('test').getCollection(collectionName);
-assert.eq(1, newNodeCollection.find({a: 1}).itcount(),
+assert.eq(1,
+          newNodeCollection.find({a: 1}).itcount(),
           'expect documents to be present in slave after replication');
 
 var signal = 15;
-replTest.stopSet( signal );
+replTest.stopSet(signal);
